// src/extension.ts
import GObject from "gi://GObject";
import St from "gi://St";
import { Extension } from "resource:///org/gnome/shell/extensions/extension.js";
import * as Main from "resource:///org/gnome/shell/ui/main.js";
import { Button } from "resource:///org/gnome/shell/ui/panelMenu.js";

// src/helper/digging.helper.ts
import GLib2 from "gi://GLib";

// src/constants/config-paths.constant.ts
import GLib from "gi://GLib";
var HOME_DIR = GLib.get_home_dir();
var CONFIG_PATHS = [
  {
    label: "Firefox",
    path: HOME_DIR + "/.mozilla/firefox/profiles.ini",
    command: "firefox"
  },
  {
    label: "Firefox (snap)",
    path: HOME_DIR + "/snap/firefox/common/.mozilla/firefox/profiles.ini",
    command: "snap run firefox"
  },
  {
    label: "Firefox (flatpak)",
    path: HOME_DIR + "/.var/app/org.mozilla.firefox/.mozilla/firefox/profiles.ini",
    command: "flatpak run org.mozilla.firefox"
  },
  {
    label: "Floorp (flatpak)",
    path: HOME_DIR + "/.var/app/one.ablaze.floorp/.floorp/profiles.ini",
    command: "flatpak run one.ablaze.floorp"
  },
  {
    label: "Zen (flatpak)",
    path: HOME_DIR + "/.var/app/app.zen_browser.zen/.zen/profiles.ini",
    command: "flatpak run app.zen_browser.zen"
  }
];

// src/helper/digging.helper.ts
function getFirefoxProfiles({ title, notify: notify2 }) {
  const browsers = CONFIG_PATHS.filter((browser) => GLib2.file_test(browser.path, GLib2.FileTest.EXISTS));
  if (browsers.length === 0) {
    notify2(title, "No supported browsers found.");
    return [];
  }
  return browsers.map((browser) => ({
    ...browser,
    profiles: getProfilesFromConfigFile(browser.path)
  }));
}
function getProfilesFromConfigFile(path) {
  let fileContent = GLib2.file_get_contents(path)[1];
  let content = fileContent.toString();
  let namePattern = /Name=(.*)/g;
  let profiles = [];
  let match;
  while ((match = namePattern.exec(content)) !== null) {
    profiles.push(match[1]);
  }
  return profiles;
}

// src/helper/menu.helper.ts
import { PopupMenuItem, PopupSeparatorMenuItem } from "resource:///org/gnome/shell/ui/popupMenu.js";

// src/helper/runner.helper.ts
import GLib3 from "gi://GLib";
function openFirefoxProfile({ command, profile, title, notify: notify2 }) {
  const fullCommand = `${command} -P ${profile} -no-remote`;
  try {
    const success = GLib3.spawn_command_line_async(fullCommand);
    if (!success) {
      notify2(title, `Failed to start Firefox with the "${profile}" profile.`);
    }
  } catch (e) {
    const message = `An error occurred while launching Firefox with the "${profile}" profile.`;
    logError(e, `[${title}] ${message}`);
    notify2(title, message);
  }
}

// src/helper/menu.helper.ts
function fillMenu({ title, menu, profiles, notify: notify2 }) {
  if ("removeAll" in menu) {
    menu.removeAll();
  }
  if ("addMenuItem" in menu) {
    profiles.forEach((browser) => {
      const section = new PopupSeparatorMenuItem(browser.label);
      menu.addMenuItem(section);
      browser.profiles.forEach((profile) => {
        const item = new PopupMenuItem(profile);
        item.connect("activate", () => openFirefoxProfile({
          command: browser.command,
          profile,
          title,
          notify: notify2
        }));
        menu.addMenuItem(item);
      });
    });
  }
}

// src/extension.ts
var FirefoxProfilesExtension = class extends Extension {
  _indicator;
  enable() {
    this._indicator = new GFirefoxProfilesIndicator(this.metadata.name);
    Main.panel.addToStatusArea(this.uuid, this._indicator);
  }
  disable() {
    if (this._indicator) {
      this._indicator.destroy();
      this._indicator = void 0;
    }
  }
};
var FirefoxProfilesIndicator = class extends Button {
  constructor(title) {
    super(0, title);
    const profiles = getFirefoxProfiles({ title, notify: Main.notify });
    this.add_child(new St.Icon({
      icon_name: "firefox-symbolic",
      // white version of the Firefox icon
      style_class: "system-status-icon"
    }));
    fillMenu({ title, menu: this.menu, profiles, notify: Main.notify });
  }
};
var GFirefoxProfilesIndicator = GObject.registerClass(FirefoxProfilesIndicator);
export {
  FirefoxProfilesExtension as default
};
